%define vim_version 7.3
%define patchlevel 316

%define perl_version %(rpm -q --qf '%%{epoch}:%%{version}' perl)
%define python_version 		2.7
%define ruby_version %(rpm -q --qf '%%{epoch}:%%{version}' ruby)

%define localedir %{buildroot}%{_datadir}/locale/

Name:           vim
Version:        %{vim_version}.%{patchlevel}
Release:        1
Summary:        VIsual editor iMproved
Url:            http://www.vim.org/
License:        Charityware
Group:          Editors
Packager: 	Igmar Palsenberg <igmar@palsenberg.com>
Source0:        %{name}-%{vim_version}.tar.bz2
Source4:        vim-%{version}-patches.tar.bz2
# Syntax highlighting for .spec files
Source5:        vim-spec-3.0.bz2
Source9:        nagios.vim

BuildRequires:  python%{python_version}-devel
BuildRequires:  perl
BuildRequires:  libtermcap-devel
BuildRequires:  libacl-devel
# We depend on an installed python2.7 and python2.7-devel
BuildRequires: 	python2.7-devel
Requires: 	python2.7
BuildRoot:      %_tmppath/%name-%version

%description
VIM (VIsual editor iMproved) is an updated and improved version of the vi
editor.  Vi was the first real screen-based editor for UNIX, and is still
very popular.  VIM improves on vi by adding new features: multiple windows,
multi-level undo, block highlighting and more.  The vim-common package
contains files which every VIM binary will need in order to run.

%package common
Summary:    The common files needed by any version of the VIM editor
Group:      Editors
Requires(pre):      coreutils
Requires(post):     coreutils
Requires(preun):    coreutils
Requires(postun):   coreutils

%description common
VIM (VIsual editor iMproved) is an updated and improved version of the vi
editor.  Vi was the first real screen-based editor for UNIX, and is still
very popular.  VIM improves on vi by adding new features: multiple windows,
multi-level undo, block highlighting and more.  The vim-common package
contains files which every VIM binary will need in order to run.

%package minimal
Summary:    A minimal version of the VIM editor
Group:      Editors
Provides:   vim

%description minimal
VIM (VIsual editor iMproved) is an updated and improved version of the vi
editor.  Vi was the first real screen-based editor for UNIX, and is still
very popular.  VIM improves on vi by adding new features: multiple windows,
multi-level undo, block highlighting and more.  The vim-minimal package
includes a minimal version of VIM, which is installed into /bin/vi for use
when only the root partition is present.

%package enhanced
Summary:    A version of the VIM editor which includes recent enhancements
Group:      Editors
Requires:   vim-common >= %version-%release
Requires:   perl = %perl_version
Provides:   vim

%description enhanced
VIM (VIsual editor iMproved) is an updated and improved version of the vi
editor.  Vi was the first real screen-based editor for UNIX, and is still
very popular.  VIM improves on vi by adding new features: multiple windows,
multi-level undo, block highlighting and more.  The vim-enhanced package
contains a version of VIM with extra, recently introduced features like
Python and Perl interpreters.

Install the vim-enhanced package if you'd like to use a version of the VIM
editor which includes recently added enhancements like interpreters for the
Python and Perl scripting languages.  You'll also need to install the
vim-common package.


%prep
%setup -q -n vim73 -a4
# spec plugin
rm -f runtime/doc/pi_spec.txt
rm -f runtime/ftpplugin/spec.vim
tar xfj %SOURCE5 -C runtime
cp -a %SOURCE9 runtime/syntax/
#official patches
for i in vim-%{version}-patches/%{vim_version}*; do
echo $i; echo $i 2>&1;
    patch -p0 -s < $i || { echo $i; exit 1; }
done

# Hackup path to the global vimrc. 
perl -pi -e 's|SYS_VIMRC_FILE "\$VIM/vimrc"|SYS_VIMRC_FILE "%_sysconfdir/vim/vimrc"|' src/os_unix.h

%build
# ensure 64bits filesizes
export CFLAGS="$RPM_OPT_FLAGS -D_GNU_SOURCE -D_FILE_OFFSET_BITS=64"
export CXXFLAGS="$RPM_OPT_FLAGS -D_GNU_SOURCE -D_FILE_OFFSET_BITS=64"

# Hacky hack : Override the Python path, else it will use the systems's version
export vi_cv_path_python=%{_bindir}/python2.7

# First build: vim-enhanced
./configure --prefix=%_prefix \
--enable-acl --enable-pythoninterp --enable-perlinterp --with-features=huge \
--enable-cscope --with-python-config-dir=%{_libdir}/python%{python_version}/config \
--libdir=%_libdir --with-compiledby="%packager" \
--with-x=no --enable-gui=no --exec-prefix=%_prefix

make
mv src/vim src/vim-enhanced
make -C src/ clean

# Second build: vim-minimal
./configure  --prefix=%_prefix \
--with-features=tiny --disable-tclinterp --disable-cscope --disable-multibyte \
--disable-hangulinput --disable-xim --disable-fontset --disable-gui \
--disable-acl --disable-pythoninterp --disable-perlinterp \
--libdir=%_libdir --with-compiledby="%packager" \
--with-x=no --enable-gui=no --exec-prefix=%_prefix --with-tlib=termcap --disable-gpm

make
cp src/vim src/vim-minimal
make -C src

%install
rm -fr %{buildroot}

perl -pi -e 's!LOCALEDIR=\$\(DEST_LANG\)!LOCALEDIR=\$(DESTDIR)\$\(prefix\)/share/locale!g' src/Makefile
mkdir -p %{buildroot}{/bin,%_bindir,%_datadir/{vim,locale},%_mandir/man1,%localedir}
make install DESTDIR=%{buildroot}


make -C src installmacros prefix=%{buildroot}%_prefix VIMRTDIR=""

install -s -m 755 src/vim-enhanced %{buildroot}%_bindir
install -s -m 755 src/vim-minimal %{buildroot}/bin/vim-minimal
pushd %{buildroot}/bin
ln -s vim-minimal vi
popd
pushd %{buildroot}/%{_bindir}
rm -f vim
ln -s vim-enhanced vim
ln -s vim vimdiff
popd

# Install the vi.1 and rvi.1 manpages
for i in %{buildroot}%_mandir/man1/{vi,rvi}; do
    cp %{buildroot}%_mandir/man1/vim.1 $i.1
done

# Link vim-common docs to normal docs
rm -fr %{buildroot}/usr/share/vim/doc
ln -sf ../../../%_defaultdocdir/%name-common/doc %{buildroot}/usr/share/vim/doc

%{find_lang} %name

mkdir -p %{buildroot}/%_sysconfdir/vim/
echo "Placeholder for global VIM config" > %{buildroot}/%_sysconfdir/vim/vimrc

%post minimal
update-alternatives --install /bin/vi vi /bin/vim-minimal 10 \
    --slave /bin/view view /bin/vim-minimal \
    --slave /bin/ex ex /bin/vim-minimal \
    --slave /bin/rvi rvi /bin/vim-minimal \
    --slave /bin/rview rview /bin/vim-minimal
update-alternatives --install /bin/vim vim /bin/vim-minimal 10 \
    --slave /bin/rvim rvim /bin/vim-minimal

%postun minimal
[ $1 = 0 ] || exit 0
update-alternatives --remove vi  /bin/vim-minimal
update-alternatives --remove vim /bin/vim-minimal

%triggerpostun minimal -- vim-minimal < 7.3
update-alternatives --remove uvi /bin/vim-minimal
for i in view ex rvi rview rvim; do
    update-alternatives --remove $i /bin/$i || :
done

%post enhanced
update-alternatives --install /bin/vi vi /usr/bin/vim-enhanced 20 \
    --slave /bin/view view /usr/bin/vim-enhanced \
    --slave /bin/ex ex /usr/bin/vim-enhanced \
    --slave /bin/rvi rvi /usr/bin/vim-enhanced \
    --slave /bin/rview rview /usr/bin/vim-enhanced
update-alternatives --install /bin/vim vim /usr/bin/vim-enhanced 20 \
    --slave /bin/rvim rvim /usr/bin/vim-enhanced

%postun enhanced
[ $1 = 0 ] || exit 0
update-alternatives --remove vi  /usr/bin/vim-enhanced
update-alternatives --remove vim /usr/bin/vim-enhanced

%clean
rm -rf %{buildroot}

%files common -f vim.lang
%defattr(-,root,root)
%doc README*.txt runtime/termcap

%dir %_datadir/vim/
%_datadir/vim/[^g]*
%_mandir/man1/vim.1*
%_mandir/man1/ex.1*
%_mandir/man1/vi.1*
%_mandir/man1/view.1*
%_mandir/man1/rvi.1*
%_mandir/man1/rview.1*
%_mandir/man1/vimdiff.1*
%_mandir/man1/vimtutor.1*
%_mandir/man1/rvim.1*
%lang(fr) %_mandir/fr*/man*/*
%lang(it) %_mandir/it*/man*/*
%lang(pl) %_mandir/pl*/man*/*
%lang(ru) %_mandir/ru*/man*/*
%exclude %_mandir/man1/evim.1*
%exclude %_bindir/rview
%exclude %_bindir/rvim
%exclude %_bindir/view
%_bindir/vimtutor
%_bindir/xxd
%_mandir/man1/xxd.1*
%config(noreplace) %_sysconfdir/vim/*

%files minimal
%defattr(-,root,root)
%doc README*.txt
/bin/vim-minimal
/bin/vi

%files enhanced
%defattr(-,root,root)
%doc README*.txt
%_bindir/ex
%_bindir/vimdiff
%_bindir/vim-enhanced
%_bindir/vim

%changelog
* Thu Sep 22 2011 Igmar Palsenberg <igmar@palsenberg.com> 7.3.316
- Initial build
